@@ -8,12 +8,22 @@ __contact__ = "Philip.Kershaw@stfc.ac.uk"
 __revision__ = "$Id$"
 
 from abc import ABCMeta, abstractmethod
+
+
 class AuthenticatorInterface(object):
     """
     Interface for user authentication.
     """
     __metaclass__ = ABCMeta
 
+    def __init__(self, typ):
+        """Initialises the authenticator
+        @type typ: str
+        @param typ: type of authenticator (usually 'client' or 'resource')
+        """
+        self.typ = typ
+        super(AuthenticatorInterface, self).__init__()
+
     @abstractmethod
     def authenticate(self, params):
         """Authenticates a user.
