@@ -22,7 +22,6 @@ from ndg.oauth.server.lib.oauth.authorize import (AuthorizeRequest,
                                                   AuthorizeResponse)
 from ndg.oauth.server.lib.oauth.oauth_exception import OauthException
 from ndg.oauth.server.lib.register.access_token import AccessTokenRegister
-from ndg.oauth.server.lib.register.client import ClientRegister
 from ndg.oauth.server.lib.register.authorization_grant import \
                                                     AuthorizationGrantRegister
 
@@ -38,11 +37,14 @@ class AuthorizationServer(object):
     MAC_TOK_ID = 'MAC'
     TOKEN_TYPES = (BEARER_TOK_ID, MAC_TOK_ID)
     
-    def __init__(self, client_register_file, authorizer, client_authenticator,
+    def __init__(self, client_register, authorizer, client_authenticator,
+                 resource_register, resource_authenticator,
                  access_token_generator, config):
-        self.client_register = ClientRegister(client_register_file)
+        self.client_register = client_register
         self.authorizer = authorizer
         self.client_authenticator = client_authenticator
+        self.resource_register = resource_register
+        self.resource_authenticator = resource_authenticator
         self.access_token_generator = access_token_generator
         self.access_token_register = AccessTokenRegister(config)
         self.authorization_grant_register = AuthorizationGrantRegister(config)
@@ -256,7 +258,6 @@ class AuthorizationServer(object):
 
         return ''.join(url_parts)
 
-
     def access_token(self, request):
         """
         Handles a request for an access token.
@@ -338,6 +339,7 @@ class AuthorizationServer(object):
                 token_request, client_id, self.access_token_register,
                 self.access_token_generator, self.authorization_grant_register,
                 request)
+
         except OauthException, exc:
             return (self._error_access_token_response(exc.error, 
                                                       exc.error_description), 
@@ -374,9 +376,12 @@ class AuthorizationServer(object):
         @return JSON formatted response
         """
         log.error("Responding with error: %s - %s", error, error_description)
+
         error_dict = {'error': error}
+
         if error_description:
             error_dict['error_description'] = error_description
+
         error_content = json.dumps(error_dict)
         return error_content
 
@@ -400,14 +405,13 @@ class AuthorizationServer(object):
         @type post_only: bool
         @param post_only: True if the HTTP method must be POST, otherwise False
 
-
         """
         if request.scheme != 'https':
             raise OauthException('invalid_request', 
                                  'Transport layer security must be used for '
                                  'this request.')
 
-        if post_only and (request.method != 'POST'):
+        if post_only and request.method != 'POST':
             raise OauthException('invalid_request', 
                                  'HTTP POST method must be used for this '
                                  'request.')
@@ -417,11 +421,11 @@ class AuthorizationServer(object):
         for key in params.iterkeys():
             count = param_counts.get(key, 0)
             param_counts[key] = count + 1
+
         for key, count in param_counts.iteritems():
             if count > 1:
                 raise OauthException('invalid_request', 
                                      'Parameter "%s" is repeated.' % key)
-        return
 
     def check_token(self, request, scope=None):
         """
@@ -429,6 +433,9 @@ class AuthorizationServer(object):
         be called from a resource service that trusts this authorization
         service. This is not part of the OAuth specification.
 
+        Only POST parameters are accepted in the request, to avoid logging
+        and caching of access tokens.
+
         Request parameters
 
         access_token
@@ -440,6 +447,8 @@ class AuthorizationServer(object):
               application/json format:
         status
               HTTP status indicating the access control decision
+        user_name
+              user identifier corresponding to access token
         error
               error as described in
               http://tools.ietf.org/html/draft-ietf-oauth-v2-22#section-5.2
@@ -457,7 +466,17 @@ class AuthorizationServer(object):
                      error description
                  )
         """
-        params = request.params
+        # only allow POST params to avoid logging and caching of access tokens
+        params = request.POST
+
+        # Check that the client is authenticated as a registered client.
+        resource_id = self.resource_authenticator.authenticate(request)
+        if resource_id is None:
+            log.warn('Resource authentication not performed')
+        else:
+            log.debug("Resource id: %s", resource_id)
+
+        # Retrieve access token
         if 'access_token' not in params:
             error = 'invalid_request'
         else:
@@ -466,9 +485,9 @@ class AuthorizationServer(object):
                 required_scope = scope
             else:
                 required_scope = params.get('scope', None)
-            error = self.access_token_register.get_token(access_token,
-                                                         required_scope)[-1]
-
+            token, error = self.access_token_register.get_token(access_token,
+                                                                required_scope)
+        # Formulate response
         status = {'invalid_request': httplib.BAD_REQUEST,
                   'invalid_token': httplib.FORBIDDEN,
                   None: httplib.OK}.get(error, httplib.BAD_REQUEST)
@@ -476,6 +495,10 @@ class AuthorizationServer(object):
         content_dict = {'status': status}
         if error:
             content_dict['error'] = error
+        else:
+            # TODO only get additional data when resource is allowed to
+            content_dict['user_name'] = token.grant.additional_data.get('user_identifier')
+
         content = json.dumps(content_dict)
         return (content, status, error)
 
@@ -517,7 +540,8 @@ class AuthorizationServer(object):
         if authorization_hdr is None:
             log.error('No Authorization header present for request to %r',
                       request.path_url)
-            error = 'invalid_request'            
+            error = 'invalid_request'
+            token = None            
         else:
             authorization_hdr_parts = authorization_hdr.split()
             if len(authorization_hdr_parts) < 2:
@@ -563,3 +587,4 @@ class AuthorizationServer(object):
                 return 'unauthorized_client', error_description
             
         return None, None
+
